
from evo_package_assistant.entity.EnumAssistantRole import EnumAssistantRole
from evo_package_assistant.entity.EAssistant import EAssistant
from evo_package_assistant.entity.EAssistantMap import EAssistantMap
from evo_package_assistant.entity.EAssistantQuery import EAssistantQuery
from evo_package_assistant.entity.EAssistantAdmin import EAssistantAdmin
from evo_package_assistant.entity.EAssistantMessage import EAssistantMessage
from evo_package_assistant.entity.EAssistantUser import EAssistantUser
from evo_package_assistant.entity.EAssistantTool import EAssistantTool
from evo_package_assistant.entity.EAssistantToolParam import EAssistantToolParam



#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_package_assistant.entity.EAssistantMessage import EAssistantMessage
from evo_package_assistant.entity.EAssistantTool import EAssistantTool

#<
from evo_framework.core.evo_core_crypto.utility.IuCryptHash import IuCryptHash
from evo_package_assistant.entity.EnumAssistantRole import EnumAssistantRole
from evo_framework.core.evo_core_api.entity import *
#>

#========================================================================================================================================
"""EAssistant

	EAssistant DESCRIPTION
	
"""
class EAssistant(EObject):

	VERSION:str="1ca1bac23a53b816a27b8d7f882f00027c03f99457e9051c27a56dc894b3c006"

	def __init__(self):
		super().__init__()
		
		self.name:str = None
		self.mapEAssistantMessage:EvoMap = EvoMap()
		self.mapEAssistantTool:EvoMap = EvoMap()
#<
		#NOT SERIALIZED
		self.callbackParser = None
		self.callback = None
		self.arrayMessage:[] = None
		self.arrayTools:[] = None
		self.arrayToolsChoice:[] = None
#>
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteStr(self.name, stream)
		self._doWriteMap(self.mapEAssistantMessage, stream)
		self._doWriteMap(self.mapEAssistantTool, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.name = self._doReadStr(stream)
		self.mapEAssistantMessage = self._doReadMap(EAssistantMessage, stream)
		self.mapEAssistantTool = self._doReadMap(EAssistantTool, stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\tname:{self.name}",
				f"\tmapEAssistantMessage:{self.mapEAssistantMessage}",
				f"\tmapEAssistantTool:{self.mapEAssistantTool}",
							]) 
		return strReturn

#<
 	#WRAPPPER
	def addMessage(self, enumAssistantRole:EnumAssistantRole, message:str, eApiFile:EApiFile = None) -> EAssistantMessage:
		if enumAssistantRole is None:
			raise Exception("ERROR_enumAssistantRole_NONE")
        
		if message is None:
			raise Exception("ERROR_message_NONE")
        
		eAssistantMessage = EAssistantMessage()
		eAssistantMessage.id = f"eAssistantMessage_{(len(self.mapEAssistantMessage.keys()))}"
		eAssistantMessage.enumAssistantRole = enumAssistantRole
		eAssistantMessage.message = message
		self.mapEAssistantMessage.doSet(eAssistantMessage)
#>  


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation    https://github.com/cyborg-ai-git # 
#========================================================================================================================================

from evo_framework import *
from evo_package_assistant.utility.UAssistant import UAssistant
from evo_package_assistant.entity import *
# ---------------------------------------------------------------------------------------------------------------------------------------
# IuAssistant
# ---------------------------------------------------------------------------------------------------------------------------------------
""" IuAssistant
"""
class IuAssistant(object):
   
    @staticmethod
    async def doSet(eAssistant:EAssistant) :
        if eAssistant is None:
            raise Exception("ERROR_eAssistant_NONE")  
        await UAssistant.getInstance().doSetEAssistant(eAssistant)
        
    @staticmethod
    async def doGet(id:str) :
        if id is None:
            raise Exception("ERROR_id_NONE")
        return await UAssistant.getInstance().doGetEAssistant(id)
        
    @staticmethod
    async def doDelEAssistant(id:str) :
        if id is None:
            raise Exception("ERROR_id_NONE")
        await UAssistant.getInstance().doDelEAssistant(id)


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework import *
from evo_package_assistant.entity import *
from evo_package_assistant.utility import *
# ---------------------------------------------------------------------------------------------------------------------------------------
# CAssistantApi
# ---------------------------------------------------------------------------------------------------------------------------------------
"""CAssistantApi
"""
class CAssistantApi(CApi):
	__instance = None
# ---------------------------------------------------------------------------------------------------------------------------------------
	def __init__(self):   
		if CAssistantApi.__instance != None:
			raise Exception("ERROR:SINGLETON")
		else:
			super().__init__()
			CAssistantApi.__instance = self
			self.current_path = os.path.dirname(os.path.abspath(__file__))
			self.path_assets:str = f"{self.current_path}/../../../../assets"
			
# ---------------------------------------------------------------------------------------------------------------------------------------
	"""getInstance Singleton

	Raises:
		Exception:  api exception

	Returns:
		_type_: CAssistantApi instance
	"""
	@staticmethod
	def getInstance():
		if CAssistantApi.__instance is None:
			cObject = CAssistantApi()  
			cObject.doInit()  
		return CAssistantApi.__instance
# ---------------------------------------------------------------------------------------------------------------------------------------
	"""doInit

	Raises:
		Exception: api exception

	Returns:

	"""   
	def doInit(self):   
		pass	  
# ---------------------------------------------------------------------------------------------------------------------------------------
	"""doAddApi

	Raises:
		Exception: api exception

	Returns:

	"""
	@override   
	def doAddApi(self):
		try:			
			
			api0 = self.newApi("assistant-set", callback=self.onSet, input=EAssistantAdmin, output=EAssistant, isEnabled=True )
			api0.isStream=True 
			api0.description="assistant-set description"

			api1 = self.newApi("assistant-get", callback=self.onGet, input=EAssistantQuery, output=EAssistant, isEnabled=True )
			api1.isStream=True 
			api1.description="assistant-get description"

			api2 = self.newApi("assistant-del", callback=self.onDel, input=EAssistantAdmin, output=EAssistant, isEnabled=True )
			api2.isStream=True 
			api2.description="assistant-del description"

			api3 = self.newApi("assistant-query", callback=self.onQuery, input=EAssistantQuery, output=EAssistantMap, isEnabled=True )
			api3.isStream=True 
			api3.description="assistant-query description"
  
		except Exception as exception:
			IuLog.doException(__name__, exception)
			raise
# ---------------------------------------------------------------------------------------------------------------------------------------

	"""onSet api callback

	Raises:
		Exception: api exception

	Returns:
		EAction:  EObject 
	"""   
	async def onSet(self,  eAction: EAction) -> EAction:
		try:
			IuLog.doDebug(__name__,f"onSet: {eAction} ")
				
			eAssistantAdmin:EAssistantAdmin = eAction.doGetInput(EAssistantAdmin)
			
			#Remove eAction input for free memory
			eAction.input = None
#<
			#++++++++++++++++++++++++++++++++++++++++++++++++++++++++
			#@TODO: INSERT YOUR CODE 

			eAssistant = EAssistant()
			eAssistant.doGenerateID()

			eAction.doSetOutput(eAssistant)
			
		  

			return eAction
			#++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#>

		except Exception as exception:
			IuLog.doException(__name__, exception)
			raise
# ---------------------------------------------------------------------------------------------------------------------------------------
	"""onGet api callback

	Raises:
		Exception: api exception

	Returns:
		EAction:  EObject 
	"""   
	async def onGet(self,  eAction: EAction) -> EAction:
		try:
			IuLog.doDebug(__name__,f"onGet: {eAction} ")
				
			eAssistantQuery:EAssistantQuery = eAction.doGetInput(EAssistantQuery)
			
			#Remove eAction input for free memory
			eAction.input = None
#<
			eAssistant = await UAssistant.getInstance().doGetEAssistantQuery(eAssistantQuery)
			eAction.doSetOutput(eAssistant)
			yield eAction
			'''
			async for eAssistant in UAssistant.getInstance().doGetEAssistantQuery(eAssistantQuery):
				eAction.doSetOutput(eAssistant)
				yield eAction
    
			'''
#>
		except Exception as exception:
			IuLog.doException(__name__, exception)
			eAction.doSetError(f"{exception}")
			yield eAction


# ---------------------------------------------------------------------------------------------------------------------------------------
	"""onDel api callback

	Raises:
		Exception: api exception

	Returns:
		EAction:  EObject 
	"""   
	async def onDel(self,  eAction: EAction) -> EAction:
		try:
			IuLog.doDebug(__name__,f"onDel: {eAction} ")
				
			eAssistantAdmin:EAssistantAdmin = eAction.doGetInput(EAssistantAdmin)
			
			#Remove eAction input for free memory
			eAction.input = None
#<
			#++++++++++++++++++++++++++++++++++++++++++++++++++++++++
			#@TODO: INSERT YOUR CODE 

			eAssistant = EAssistant()
			eAssistant.doGenerateID()

			eAction.doSetOutput(eAssistant)
			
		  

			return eAction
			#++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#>

		except Exception as exception:
			IuLog.doException(__name__, exception)
			raise
# ---------------------------------------------------------------------------------------------------------------------------------------
	"""onQuery api callback

	Raises:
		Exception: api exception

	Returns:
		EAction:  EObject 
	"""   
	async def onQuery(self,  eAction: EAction) -> EAction:
		try:
			IuLog.doDebug(__name__,f"onQuery: {eAction} ")
				
			eAssistantQuery:EAssistantQuery = eAction.doGetInput(EAssistantQuery)
			
			#Remove eAction input for free memory
			eAction.input = None
   
#<			

			async for eAssistantMap in UAssistant.getInstance().doQuery(eAssistantQuery):
				eAction.doSetOutput(eAssistantMap)
				yield eAction		
#>
		except Exception as exception:
			IuLog.doException(__name__, exception)
			eAction.doSetError(f"{exception}")
			yield eAction
# ---------------------------------------------------------------------------------------------------------------------------------------


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation    https://github.com/cyborg-ai-git # 
#========================================================================================================================================

from evo_framework import *
from evo_package_assistant.entity import *
import importlib.util
from pathlib import Path
# ---------------------------------------------------------------------------------------------------------------------------------------
# UAssistant
# ---------------------------------------------------------------------------------------------------------------------------------------
""" UAssistant
"""
class UAssistant:  
    __instance = None

    def __init__(self):
        if UAssistant.__instance != None:
            raise Exception("ERROR_SINGLETON")
        else:
            UAssistant.__instance = self  
            self.path_assistant:str = "/Users/max/Documents/GIT_HUGGINGFACE/cyborgai-api-beta/assets/assistant_a/"  
            self.eAssistantMap:EAssistantMap = None
# -----------------------------------------------------------------------------
    @staticmethod
    def getInstance():
        if UAssistant.__instance == None:
            uObject = UAssistant()
            uObject.doInit()
            
        return UAssistant.__instance
# -----------------------------------------------------------------------------
    def doInit(self):
        try:
            self.eAssistantMap = EAssistantMap()
            self.eAssistantMap.doGenerateID()
            
            self.__doLoadDirEAssistant()
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
        
# -----------------------------------------------------------------------------   
    async def doSetEAssistant(self, eAssistant:EAssistant):
        try:
           self.eAssistantMap.mapEAssistant.doSet(eAssistant)
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
        
# -----------------------------------------------------------------------------   
    async def  doGetEAssistantQuery(self, eAssistantQuery:EAssistantQuery) -> EAssistant :
        try:
            if eAssistantQuery is None:
                raise Exception("ERROR_eAssistantQuery_NONE")
            
            if eAssistantQuery.query is None:
                raise Exception("ERROR_eAssistantQuery.query_NONE")
            
            arrayQuery = eAssistantQuery.query.split("=")
            
            if len(arrayQuery) != 2 and arrayQuery[0].lower() != "id":
                raise Exception("ERROR_eAssistantQuery.query_id_NONE")
                
            eAssistantID= arrayQuery[-1]
            
            return await self.doGetEAssistant(eAssistantID)
            
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
# -----------------------------------------------------------------------------   
    async def doGetEAssistant(self, id) -> EAssistant:
        try:
            if id in self.eAssistantMap.mapEAssistant.keys():
                return self.eAssistantMap.mapEAssistant.doGet(id)
            
            raise Exception(f"ERROR_NOT_FOUD_ASSISTANT_{id}")
            
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
# -----------------------------------------------------------------------------   
    async def doQuery(self, eAssistantQuery:EAssistantQuery) -> EAssistantMap:
        try:
            #TODO:query
            yield self.eAssistantMap
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
# -----------------------------------------------------------------------------   
    async def doDelEAssistant(self, id):
        try:
            self.eAssistantMap.mapEAssistant.doDel(id)
        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
#-------------------------------------------------------------------------------
    def __doLoadDirEAssistant(self):
        try:
            IuLog.doVerbose(__name__, f"self.path_assistant {self.path_assistant}")
            
            directory = Path(self.path_assistant)
            
            arrayFileAssistant = [str(file) for file in directory.rglob('assistant_*.py')]
            print(arrayFileAssistant)
            
          
            
            for pathAssistant in arrayFileAssistant:
                print(pathAssistant)
      
                # Create a module spec from the file location
                spec = importlib.util.spec_from_file_location("assistant", pathAssistant)

                # Create a new module based on the spec
                external_file = importlib.util.module_from_spec(spec)

                # Execute the module in its own namespace
                spec.loader.exec_module(external_file)
                
                #print(pathAssistant.eAssistant)

                # Now you can use functions and variables from the external file
                #pathAssistant.addAssistant()
                

        except Exception as exception:
            IuLog.doException(__name__,exception)
            raise
         


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_package_assistant.entity.EAssistantToolParam import EAssistantToolParam
#========================================================================================================================================
"""EAssistantTool

	EAssistantTool DESCRIPTION
	
"""
class EAssistantTool(EObject):

	VERSION:str="028f6050ba8d7d4336167f4be16ceeeb2b1f673358494dc95ad26c2855f5cde6"

	def __init__(self):
		super().__init__()
		
		self.description:str = None
		self.mapEAssistantToolParam:EvoMap = EvoMap()
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteStr(self.description, stream)
		self._doWriteMap(self.mapEAssistantToolParam, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.description = self._doReadStr(stream)
		self.mapEAssistantToolParam = self._doReadMap(EAssistantToolParam, stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\tdescription:{self.description}",
				f"\tmapEAssistantToolParam:{self.mapEAssistantToolParam}",
							]) 
		return strReturn
	


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_framework.core.evo_core_api.entity.EApiAdmin import EApiAdmin
from evo_package_assistant.entity.EAssistantMessage import EAssistantMessage
#========================================================================================================================================
"""EAssistantAdmin

	EAssistantAdmin DESCRIPTION
	
"""
class EAssistantAdmin(EObject):

	VERSION:str="683cafa6f5264a05f1b74a80cd882f81fe8d5e594509e256b31057e94095e115"

	def __init__(self):
		super().__init__()
		
		self.eApiAdmin:EApiAdmin = None
		self.eAssistantMessage:EAssistantMessage = None
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteEObject(self.eApiAdmin, stream)
		self._doWriteEObject(self.eAssistantMessage, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.eApiAdmin = self._doReadEObject(EApiAdmin, stream)
		self.eAssistantMessage = self._doReadEObject(EAssistantMessage, stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\teApiAdmin:{self.eApiAdmin}",
				f"\teAssistantMessage:{self.eAssistantMessage}",
							]) 
		return strReturn
	


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git # 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

#========================================================================================================================================
"""EAssistantCallbackItem

	EAssistantTool DESCRIPTION
	
"""
class EAssistantCallbackItem(EObject):

	VERSION:str="010c127195308e0bc1d956b7b20b029c4b2729bd87a8310d2c83d39ae2e95af8"

	def __init__(self):
		super().__init__()
		
		self.name:str = None
		self.type:str = None
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteStr(self.name, stream)
		self._doWriteStr(self.type, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.name = self._doReadStr(stream)
		self.type = self._doReadStr(stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\tname:{self.name}",
				f"\ttype:{self.type}",
							]) 
		return strReturn
	


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_package_assistant.entity.EAssistantMessage import EAssistantMessage
#========================================================================================================================================
"""EAssistantUser

	EAssistant DESCRIPTION
	
"""
class EAssistantUser(EObject):

	VERSION:str="932a478c9321d2214a801556420e950f3ea46c555f07062868f08bf98bc6b95e"

	def __init__(self):
		super().__init__()
		
		self.eAssistanID:str = None
		self.mapEAssistantMessage:EvoMap = EvoMap()
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteStr(self.eAssistanID, stream)
		self._doWriteMap(self.mapEAssistantMessage, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.eAssistanID = self._doReadStr(stream)
		self.mapEAssistantMessage = self._doReadMap(EAssistantMessage, stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\teAssistanID:{self.eAssistanID}",
				f"\tmapEAssistantMessage:{self.mapEAssistantMessage}",
							]) 
		return strReturn
	


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation    https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_package_assistant.entity.EAssistant import EAssistant
#========================================================================================================================================
"""EAssistantMap

    EAssistant DESCRIPTION
    
"""
class EAssistantMap(EObject):

    VERSION:str="6ba6c078d431ad0fb67f4903e9ea8825454016938b8cfc3e270c74d6cb4c3d41"

    def __init__(self):
        super().__init__()
        
        self.mapEAssistant:EvoMap = EvoMap()
  
    def toStream(self, stream):
        super().toStream(stream)
        
        self._doWriteMap(self.mapEAssistant, stream)
        
    def fromStream(self, stream):
        super().fromStream(stream)
        
        self.mapEAssistant = self._doReadMap(EAssistant, stream)
    
    def __str__(self) -> str:
        strReturn = "\n".join([
                super().__str__(),
                            
                f"\tmapEAssistant:{self.mapEAssistant}",
                            ]) 
        return strReturn
    


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

from evo_package_assistant.entity.EnumAssistantRole import EnumAssistantRole
from evo_framework.core.evo_core_api.entity.EApiFile import EApiFile
#========================================================================================================================================
"""EAssistantMessage

	EAssistantChat DESCRIPTION
	
"""
class EAssistantMessage(EObject):

	VERSION:str="caf2e977bb9058e42e04c79c46c1fc13cdf9283b08860676a64728542d6ac335"

	def __init__(self):
		super().__init__()
		
		self.enumAssistantRole:EnumAssistantRole = EnumAssistantRole.USER
		self.message:str = None
		self.eApiFile:EApiFile = None
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteInt(self.enumAssistantRole.value, stream)
		self._doWriteStr(self.message, stream)
		self._doWriteEObject(self.eApiFile, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.enumAssistantRole = EnumAssistantRole(self._doReadInt(stream))
		self.message = self._doReadStr(stream)
		self.eApiFile = self._doReadEObject(EApiFile, stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\tenumAssistantRole:{self.enumAssistantRole}",
				f"\tmessage:{self.message}",
				f"\teApiFile:{self.eApiFile}",
							]) 
		return strReturn
	


from evo_framework import *
import re
class CAssistantCallbackStream:
    def __init__(self):
        self.isParseHeader:bool = True
        self.header:str = None
        self.prefixID:str = ""
        self.messageFull:str = ""
        self.count:int = 0
        self.messageHeader:str = None
        self.headerPattern = r'\[.*?\]'
        self.isRemoveHeader:bool = True
        self.chunkHeader:int = -1
        self.totenTot:int=0
   
    @abstractmethod
    def onParser(self, message:str) -> EApiText: 
        eApiText= self.doParser(message)
        return eApiText
    
    def isHeaderComplete(self, message) ->bool:
        if not self.isParseHeader:
                self.header="no"
                return True

        if self.header is None:
            self.messageFull = "".join([self.messageFull, message])
            match = re.search(self.headerPattern, self.messageFull)
            
            if match:
                self.header=match.group().replace("[","").replace("]", "")
                self.chunkHeader = self.count
                return True
            else:
                return False
        
        return True
    
    def doParser(self, message:str) -> EApiText: 
        eApiText = EApiText()
        eApiText.id = f"{self.prefixID}{self.count}"  
        messageChunk=message
        self.totenTot +=1
        eApiText.tokenTot = self.totenTot

        if message is None:
            eApiText.isComplete = True      
        else:
            if self.isHeaderComplete(message):
                eApiText.header = self.header
                if self.isRemoveHeader:
                    if self.count == self.chunkHeader:
                        messageChunk = message.replace(self.header, "")
                              
        eApiText.text = messageChunk
        self.count +=1
        return eApiText
    


#========================================================================================================================================
# CyborgAI CC BY-NC-ND 4.0 Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 Internation	https://github.com/cyborg-ai-git | 
#========================================================================================================================================

from evo_framework.entity.EObject import EObject
from evo_framework.core.evo_core_type.entity.EvoMap import EvoMap

#========================================================================================================================================
"""EAssistantToolParam

	EAssistantToolParam DESCRIPTION
	
"""
class EAssistantToolParam(EObject):

	VERSION:str="c897fff31b14bb5a1e721cbeba2291204f3b6c74079a14714a9b56ff1aa2c0f9"

	def __init__(self):
		super().__init__()
		
		self.type:str = None
		self.isRequired:bool = True
  
	def toStream(self, stream):
		super().toStream(stream)
		
		self._doWriteStr(self.type, stream)
		self._doWriteBool(self.isRequired, stream)
		
	def fromStream(self, stream):
		super().fromStream(stream)
		
		self.type = self._doReadStr(stream)
		self.isRequired = self._doReadBool(stream)
	
	def __str__(self) -> str:
		strReturn = "\n".join([
				super().__str__(),
							
				f"\ttype:{self.type}",
				f"\tisRequired:{self.isRequired}",
							]) 
		return strReturn
	